package com.ruoyi.system.answer.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.answer.base.domain.QuestionMatch;
import com.ruoyi.system.answer.base.service.IQuestionMatchService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 每日答题赛Controller
 * 
 * @author ruoyi
 * @date 2024-09-13
 */
@RestController
@RequestMapping("/qusestion_match")
public class QuestionMatchController extends BaseController
{
    @Autowired
    private IQuestionMatchService questionMatchService;

    /**
     * 查询每日答题赛列表
     */
    @RequiresPermissions("system:qusestion_match:list")
    @GetMapping("/list")
    public TableDataInfo list(QuestionMatch questionMatch)
    {
        startPage();
        List<QuestionMatch> list = questionMatchService.selectQuestionMatchList(questionMatch);
        return getDataTable(list);
    }

    /**
     * 导出每日答题赛列表
     */
    @RequiresPermissions("system:qusestion_match:export")
    @Log(title = "每日答题赛", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, QuestionMatch questionMatch)
    {
        List<QuestionMatch> list = questionMatchService.selectQuestionMatchList(questionMatch);
        ExcelUtil<QuestionMatch> util = new ExcelUtil<QuestionMatch>(QuestionMatch.class);
        util.exportExcel(response, list, "每日答题赛数据");
    }

    /**
     * 获取每日答题赛详细信息
     */
    @RequiresPermissions("system:qusestion_match:query")
    @GetMapping(value = "/{matchId}")
    public AjaxResult getInfo(@PathVariable("matchId") Long matchId)
    {
        return success(questionMatchService.selectQuestionMatchByMatchId(matchId));
    }

    /**
     * 新增每日答题赛
     */
    @RequiresPermissions("system:qusestion_match:add")
    @Log(title = "每日答题赛", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody QuestionMatch questionMatch)
    {
        return toAjax(questionMatchService.insertQuestionMatch(questionMatch));
    }

    /**
     * 修改每日答题赛
     */
    @RequiresPermissions("system:qusestion_match:edit")
    @Log(title = "每日答题赛", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody QuestionMatch questionMatch)
    {
        return toAjax(questionMatchService.updateQuestionMatch(questionMatch));
    }

    /**
     * 删除每日答题赛
     */
    @RequiresPermissions("system:qusestion_match:remove")
    @Log(title = "每日答题赛", businessType = BusinessType.DELETE)
	@DeleteMapping("/{matchIds}")
    public AjaxResult remove(@PathVariable Long[] matchIds)
    {
        return toAjax(questionMatchService.deleteQuestionMatchByMatchIds(matchIds));
    }
}
