package com.ruoyi.system.answer.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.answer.base.domain.QuestionMatchOnehundred;
import com.ruoyi.system.answer.base.service.IQuestionMatchOnehundredService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 百元挑战赛Controller
 * 
 * @author ruoyi
 * @date 2024-09-13
 */
@RestController
@RequestMapping("/onehundred")
public class QuestionMatchOnehundredController extends BaseController
{
    @Autowired
    private IQuestionMatchOnehundredService questionMatchOnehundredService;

    /**
     * 查询百元挑战赛列表
     */
    @RequiresPermissions("system:onehundred:list")
    @GetMapping("/list")
    public TableDataInfo list(QuestionMatchOnehundred questionMatchOnehundred)
    {
        startPage();
        List<QuestionMatchOnehundred> list = questionMatchOnehundredService.selectQuestionMatchOnehundredList(questionMatchOnehundred);
        return getDataTable(list);
    }

    /**
     * 导出百元挑战赛列表
     */
    @RequiresPermissions("system:onehundred:export")
    @Log(title = "百元挑战赛", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, QuestionMatchOnehundred questionMatchOnehundred)
    {
        List<QuestionMatchOnehundred> list = questionMatchOnehundredService.selectQuestionMatchOnehundredList(questionMatchOnehundred);
        ExcelUtil<QuestionMatchOnehundred> util = new ExcelUtil<QuestionMatchOnehundred>(QuestionMatchOnehundred.class);
        util.exportExcel(response, list, "百元挑战赛数据");
    }

    /**
     * 获取百元挑战赛详细信息
     */
    @RequiresPermissions("system:onehundred:query")
    @GetMapping(value = "/{matchId}")
    public AjaxResult getInfo(@PathVariable("matchId") Long matchId)
    {
        return success(questionMatchOnehundredService.selectQuestionMatchOnehundredByMatchId(matchId));
    }

    /**
     * 新增百元挑战赛
     */
    @RequiresPermissions("system:onehundred:add")
    @Log(title = "百元挑战赛", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody QuestionMatchOnehundred questionMatchOnehundred)
    {
        return toAjax(questionMatchOnehundredService.insertQuestionMatchOnehundred(questionMatchOnehundred));
    }

    /**
     * 修改百元挑战赛
     */
    @RequiresPermissions("system:onehundred:edit")
    @Log(title = "百元挑战赛", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody QuestionMatchOnehundred questionMatchOnehundred)
    {
        return toAjax(questionMatchOnehundredService.updateQuestionMatchOnehundred(questionMatchOnehundred));
    }

    /**
     * 删除百元挑战赛
     */
    @RequiresPermissions("system:onehundred:remove")
    @Log(title = "百元挑战赛", businessType = BusinessType.DELETE)
	@DeleteMapping("/{matchIds}")
    public AjaxResult remove(@PathVariable Long[] matchIds)
    {
        return toAjax(questionMatchOnehundredService.deleteQuestionMatchOnehundredByMatchIds(matchIds));
    }
}
